diff --git a/django/test/testcases.py b/django/test/testcases.py
index 2f8acad..6eca030 100644
--- a/django/test/testcases.py
+++ b/django/test/testcases.py
@@ -347,7 +347,7 @@ class TransactionTestCase(unittest.TestCase):
     def assertContains(self, response, text, count=None, status_code=200,
                        msg_prefix=''):
         """
         Asserts that a response indicates that a page was retrieved
         successfully, (i.e., the HTTP status code was as expected), and that
         ``text`` occurs ``count`` times in the content of the response.
         If ``count`` is None, the count doesn't matter - the assertion is true
@@ -357,7 +357,7 @@ class TransactionTestCase(unittest.TestCase):
             msg_prefix += ": "
 
         self.assertEqual(response.status_code, status_code,
-            msg_prefix + "Couldn't retrieve page: Response code was %d"
+            msg_prefix + "Couldn't retrieve content: Response code was %d"
             " (expected %d)" % (response.status_code, status_code))
         text = smart_str(text, response._charset)
         real_count = response.content.count(text)
@@ -372,7 +372,7 @@ class TransactionTestCase(unittest.TestCase):
     def assertNotContains(self, response, text, status_code=200,
                           msg_prefix=''):
         """
         Asserts that a response indicates that a page was retrieved
         successfully, (i.e., the HTTP status code was as expected), and that
         ``text`` doesn't occurs in the content of the response.
         """
@@ -380,7 +380,7 @@ class TransactionTestCase(unittest.TestCase):
             msg_prefix += ": "
 
         self.assertEqual(response.status_code, status_code,
-            msg_prefix + "Couldn't retrieve page: Response code was %d"
+            msg_prefix + "Couldn't retrieve content: Response code was %d"
             " (expected %d)" % (response.status_code, status_code))
         text = smart_str(text, response._charset)
         self.assertEqual(response.content.count(text), 0,
@@ -347,7 +347,7 @@ class TransactionTestCase(unittest.TestCase):
                        msg_prefix=''):
         """
-        Asserts that a response indicates that a page was retrieved
+        Asserts that a response indicates that a page/content was retrieved
         successfully, (i.e., the HTTP status code was as expected), and that
         ``text`` occurs ``count`` times in the content of the response.
@@ -372,7 +372,7 @@ class TransactionTestCase(unittest.TestCase):
                           msg_prefix=''):
         """
-        Asserts that a response indicates that a page was retrieved
+        Asserts that a response indicates that a page/content was retrieved
         successfully, (i.e., the HTTP status code was as expected), and that
         ``text`` doesn't occurs in the content of the response.
